/* eslint comma-dangle: ["error", "always-multiline"] */

// Import components core
import Vue from 'vue';
import { Loading } from 'element-ui'
import './_style/global.styl'
import {transformCamelCase, warn} from './_util'
import TimeButton from './time-button'
import Dialog from './dialog'
import Upload from './upload'
import Form from './form'
import Table from './table'
import Tinymce from './tinymce'
import FormJsx from './form-jsx'
import SvgIcon from './svg-icon'
import CustormTable from './custorm-table'

// Totally importing reminder
warn(
  'You are using a whole package of jdc-vue-toolkit, ' +
    'please use https://www.npmjs.com/package/babel-plugin-import to reduce app bundle size.',
  'warn',
)

/* global MAN_VERSION */
const version = /* @echo MAN_VERSION */ MAN_VERSION

Vue.use(Loading.directive);

export const components = {
  TimeButton,
  Dialog,
  Upload,
  Form,
  Table,
  Tinymce,
  FormJsx,
  SvgIcon,
  CustormTable,
}

// Define plugin installation method
const install = function(Vue) {
  if (!Vue || install.installed) {
    return
  }

  // Register global components
  const componentsNames = Object.keys(components)
  componentsNames.forEach(name => {
    const component = components[name]
    if (component.name) {
      Vue.component(component.name, component) // kebab-case
      Vue.component(transformCamelCase(`-${component.name}`), component) // PascalCase
    }
  })
}

if (typeof window !== 'undefined' && window.Vue) {
  install(window.Vue)
}

// export components
export {
  install,
  version,
  TimeButton,
  Dialog,
  Upload,
  Form,
  Table,
  Tinymce,
  FormJsx,
  SvgIcon,
  CustormTable,
}

export default {
  install,
  version,
}
