(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(['exports'], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports);
    global.dynamicLoadScript = mod.exports;
  }
})(this, function (exports) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  var callbacks = [];

  function loadedTinymce() {
    // to fixed https://github.com/PanJiaChen/vue-element-admin/issues/2144
    // check is successfully downloaded script
    return window.tinymce;
  }

  var dynamicLoadScript = function dynamicLoadScript(src, callback) {
    var existingScript = document.getElementById(src);
    var cb = callback || function () {};

    if (!existingScript) {
      var script = document.createElement('script');
      script.src = src; // src url for the third-party library being loaded.
      script.id = src;
      document.body.appendChild(script);
      callbacks.push(cb);
      // eslint-disable-next-line no-use-before-define
      var onEnd = 'onload' in script ? stdOnEnd : ieOnEnd;
      onEnd(script);
    }

    if (existingScript && cb) {
      if (loadedTinymce()) {
        cb(null, existingScript);
      } else {
        callbacks.push(cb);
      }
    }

    function stdOnEnd(script) {
      script.onload = function () {
        // this.onload = null here is necessary
        // because even IE9 works not like others
        this.onerror = this.onload = null;
        var _iteratorNormalCompletion = true;
        var _didIteratorError = false;
        var _iteratorError = undefined;

        try {
          for (var _iterator = callbacks[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
            var _cb = _step.value;

            _cb(null, script);
          }
        } catch (err) {
          _didIteratorError = true;
          _iteratorError = err;
        } finally {
          try {
            if (!_iteratorNormalCompletion && _iterator.return) {
              _iterator.return();
            }
          } finally {
            if (_didIteratorError) {
              throw _iteratorError;
            }
          }
        }

        callbacks = null;
      };
      script.onerror = function () {
        this.onerror = this.onload = null;
        cb(new Error('Failed to load ' + src), script);
      };
    }

    function ieOnEnd(script) {
      script.onreadystatechange = function () {
        if (this.readyState !== 'complete' && this.readyState !== 'loaded') {
          return;
        }
        this.onreadystatechange = null;
        var _iteratorNormalCompletion2 = true;
        var _didIteratorError2 = false;
        var _iteratorError2 = undefined;

        try {
          for (var _iterator2 = callbacks[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
            var _cb2 = _step2.value;

            _cb2(null, script); // there is no way to catch loading errors in IE8
          }
        } catch (err) {
          _didIteratorError2 = true;
          _iteratorError2 = err;
        } finally {
          try {
            if (!_iteratorNormalCompletion2 && _iterator2.return) {
              _iterator2.return();
            }
          } finally {
            if (_didIteratorError2) {
              throw _iteratorError2;
            }
          }
        }

        callbacks = null;
      };
    }
  };

  exports.default = dynamicLoadScript;
});