;(function(){
(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(['exports', 'axios', './EditorImage', './plugins', './toolbar', './dynamicLoadScript', '../_style/global.css', './style/index.css'], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require('axios'), require('./EditorImage'), require('./plugins'), require('./toolbar'), require('./dynamicLoadScript'), require('../_style/global.css'), require('./style/index.css'));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.axios, global.EditorImage, global.plugins, global.toolbar, global.dynamicLoadScript, global.global, global.index);
    global.index = mod.exports;
  }
})(this, function (exports, _axios, _EditorImage, _plugins, _toolbar, _dynamicLoadScript) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  var _axios2 = _interopRequireDefault(_axios);

  var _EditorImage2 = _interopRequireDefault(_EditorImage);

  var _plugins2 = _interopRequireDefault(_plugins);

  var _toolbar2 = _interopRequireDefault(_toolbar);

  var _dynamicLoadScript2 = _interopRequireDefault(_dynamicLoadScript);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  var tinymceCDN = 'https://cdn.jsdelivr.net/npm/tinymce@5.1.4/tinymce.min.js';
  var tinymceLanguageCDN = 'http://storage.jd.com/web-uc-static/components-dependencies/tinymce_zh_CN.js?Expires=3724076573&AccessKey=XOZfrjeQBISYqdZa&Signature=xFtfc%2BE%2F5v94QL5CDrdS397cNg4%3D';

  exports.default = {
    name: 'uc-tinymce',
    components: { editorImage: _EditorImage2.default },
    props: {
      id: {
        type: String,
        default: function _default() {
          return 'vue-tinymce-' + +new Date() + ((Math.random() * 1000).toFixed(0) + '');
        }
      },
      value: {
        type: String,
        default: ''
      },
      toolbar: {
        type: Array,
        required: false,
        default: function _default() {
          return [];
        }
      },
      menubar: {
        type: String,
        default: 'file edit insert view format table'
      },
      height: {
        type: [Number, String],
        required: false,
        default: 360
      },
      width: {
        type: [Number, String],
        required: false,
        default: 'auto'
      },
      customToolbar: {
        type: Boolean,
        required: false,
        default: false
      },
      fileUploadUrl: {
        type: String,
        required: false,
        default: 'https://httpbin.org/post'
      },
      fileType: {
        type: String,
        required: false,
        default: 'base64' },
      fileUrlFormatter: {
        type: Function,
        required: false,
        default: function _default(data) {
          return data.files.file;
        }
      }
    },
    data: function data() {
      return {
        hasChange: false,
        hasInit: false,
        tinymceId: this.id,
        fullscreen: false,
        languageTypeList: {
          'en': 'en',
          'zh': 'zh_CN',
          'es': 'es_MX',
          'ja': 'ja'
        }
      };
    },

    computed: {
      slotProps: function slotProps() {
        return {
          value: this.value,
          tinymceId: this.tinymceId
        };
      },
      containerWidth: function containerWidth() {
        var width = this.width;
        if (/^[\d]+(\.[\d]+)?$/.test(width)) {
          return width + 'px';
        }
        return width;
      }
    },
    watch: {
      value: function value(val) {
        var _this2 = this;

        if (!this.hasChange && this.hasInit) {
          this.$nextTick(function () {
            return window.tinymce.get(_this2.tinymceId).setContent(val || '');
          });
        }
      }
    },
    mounted: function mounted() {
      this._initData();
    },
    activated: function activated() {
      if (window.tinymce) {
        this._initTinymce();
      }
    },
    deactivated: function deactivated() {
      this.destroyTinymce();
    },
    destroyed: function destroyed() {
      this.destroyTinymce();
    },

    methods: {
      _showLoading: function _showLoading(modal) {
        var modalContent = document.querySelector('.el-loading-mask');
        if (modalContent) {
          Object.assign(modalContent.style, { display: 'flex', 'z-index': 1 });
        } else {
          modalContent = document.createElement('div');
          Object.assign(modalContent.style, {
            position: 'absolute',
            top: 0,
            background: 'rgba(255,255,255,.9)',
            display: 'flex',
            'align-items': 'center',
            'justify-content': 'center'
          });
          modalContent.className = 'el-loading-mask';
          modalContent.innerHTML = '\n          <div class="el-loading-spinner">\n            <svg viewBox="25 25 50 50" class="circular">\n              <circle cx="50" cy="50" r="20" fill="none" class="path"></circle>\n            </svg>\n            <p class="el-loading-text">\u6587\u4EF6\u4E0A\u4F20\u4E2D</p>\n          </div>';
          modal.appendChild(modalContent);
        }
      },
      _hideLoading: function _hideLoading() {
        var loading = document.querySelector('.el-loading-mask');
        Object.assign(loading.style, { display: 'none', 'z-index': -1 });
      },
      _initData: function _initData() {
        var _this3 = this;

        (0, _dynamicLoadScript2.default)(tinymceCDN, function (err) {
          if (err) {
            _this3.$message.error(err.message);
            return;
          }
          _this3._initTinymce();
        });
      },
      _initTinymce: function _initTinymce() {
        var _this4 = this;

        var _this = this;
        var fileType = this.fileType,
            fileUploadUrl = this.fileUploadUrl,
            _showLoading = this._showLoading,
            _hideLoading = this._hideLoading,
            fileUrlFormatter = this.fileUrlFormatter;

        window.tinymce.init({
          selector: '#' + this.tinymceId,
          language: this.languageTypeList['zh'],
          language_url: tinymceLanguageCDN,
          height: this.height,
          automatic_uploads: true,
          file_picker_types: 'media,image',

          file_picker_callback: function file_picker_callback(cb, value, meta) {
            var types = { media: 'video/*', image: 'image/*' };
            var input = document.createElement('input');
            input.setAttribute('type', 'file');
            input.setAttribute('accept', types[meta.filetype]);
            input.onchange = function () {
              var file = this.files[0];
              if (fileType === 'base64') {
                var reader = new FileReader();
                reader.onload = function () {
                  var id = 'blobid' + new Date().getTime();
                  var blobCache = window.tinymce.activeEditor.editorUpload.blobCache;
                  var base64 = reader.result.split(',')[1];
                  var blobInfo = blobCache.create(id, file, base64);
                  blobCache.add(blobInfo);

                  cb(blobInfo.blobUri(), { title: file.name });
                };
                reader.readAsDataURL(file);
              } else {
                var modal = document.querySelector('.tox-dialog');
                var formData = new FormData();
                _showLoading(modal);

                formData.set('file', file);
                try {
                  (0, _axios2.default)({
                    url: fileUploadUrl,
                    method: 'post',
                    data: formData
                  }).then(function (_ref) {
                    var data = _ref.data;

                    var fileUrl = fileUrlFormatter(data);
                    cb(fileUrl, { title: file.name, style: 'object-fit: cover;', width: '100%', height: 'auto' });
                    _hideLoading(modal);
                  });
                } catch (error) {
                  _hideLoading(modal);
                }
              }
            };
            input.click();
          },
          body_class: 'panel-body ',
          object_resizing: false,
          toolbar: this.toolbar.length > 0 ? this.toolbar : _toolbar2.default,
          menubar: this.menubar,
          plugins: _plugins2.default,
          end_container_on_empty_block: true,
          powerpaste_word_import: 'clean',
          code_dialog_height: 450,
          code_dialog_width: 1000,
          advlist_bullet_styles: 'square',
          advlist_number_styles: 'default',
          imagetools_cors_hosts: ['www.tinymce.com', 'codepen.io'],
          default_link_target: '_blank',
          link_title: false,
          nonbreaking_force_tab: true,
          init_instance_callback: function init_instance_callback(editor) {
            if (_this.value) {
              editor.setContent(_this.value);
            }
            _this.hasInit = true;
            editor.on('NodeChange Change KeyUp SetContent', function () {
              _this4.hasChange = true;
              _this4.$emit('input', editor.getContent());
            });
          },
          setup: function setup(editor) {
            editor.on('FullscreenStateChanged', function (e) {
              _this.fullscreen = e.state;
            });
          }
        });
      },
      destroyTinymce: function destroyTinymce() {
        var tinymce = window.tinymce.get(this.tinymceId);
        if (this.fullscreen) {
          tinymce.execCommand('mceFullScreen');
        }

        if (tinymce) {
          tinymce.destroy();
        }
      },
      setContent: function setContent(value) {
        window.tinymce.get(this.tinymceId).setContent(value);
      },
      getContent: function getContent() {
        window.tinymce.get(this.tinymceId).getContent();
      },
      imageSuccessCBK: function imageSuccessCBK(arr) {
        var _this = this;
        arr.forEach(function (v) {
          window.tinymce.get(_this.tinymceId).insertContent('<img class="wscnph" src="' + v.url + '" >');
        });
      }
    }
  };
});
})()
if (module.exports.__esModule) module.exports = module.exports.default
var __vue__options__ = (typeof module.exports === "function"? module.exports.options: module.exports)
__vue__options__.render = function render () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"uc-tinymce__container",class:{fullscreen:_vm.fullscreen},style:({width:_vm.containerWidth})},[_c('textarea',{staticClass:"uc-tinymce__textarea",attrs:{"id":_vm.tinymceId}}),_vm._v(" "),(_vm.customToolbar)?_c('div',{staticClass:"uc-tinymce__btn-container"},[_vm._t("customToolbar",[_c('editorImage',{staticClass:"uc-tinymce__upload-btn",attrs:{"url":_vm.fileUploadUrl,"fileUrlFormatter":_vm.fileUrlFormatter},on:{"successCBK":_vm.imageSuccessCBK}})],{"value":_vm.value})],2):_vm._e()])}
__vue__options__.staticRenderFns = []
